is_internal_only

Function is_internal_only 

const fn is_internal_only(f: &Function<'_>) -> bool
Internal functions and modifiers are only reachable from the compilation unit, so their parameters can be proven safe from the invocation sites seen there.